@@ -33,7 +33,7 @@ CrystalDocs.runQuery = function(query) {
     }
     if (matches.length > 0) {
       results.push({
-        id: type.id,
+        id: type.html_id,
         result_type: "type",
         kind: type.kind,
         name: name,
@@ -45,25 +45,36 @@ CrystalDocs.runQuery = function(query) {
       });
     }
 
-    type.instance_methods.forEach(function(method) {
-      searchMethod(method, type, "instance_method", query, results);
-    })
-    type.class_methods.forEach(function(method) {
-      searchMethod(method, type, "class_method", query, results);
-    })
-    type.constructors.forEach(function(constructor) {
-      searchMethod(constructor, type, "constructor", query, results);
-    })
-    type.macros.forEach(function(macro) {
-      searchMethod(macro, type, "macro", query, results);
-    })
-    type.constants.forEach(function(constant){
-      searchConstant(constant, type, query, results);
-    });
-
-    type.types.forEach(function(subtype){
-      searchType(subtype, query, results);
-    });
+    if (type.instance_methods) {
+      type.instance_methods.forEach(function(method) {
+        searchMethod(method, type, "instance_method", query, results);
+      })
+    }
+    if (type.class_methods) {
+      type.class_methods.forEach(function(method) {
+        searchMethod(method, type, "class_method", query, results);
+      })
+    }
+    if (type.constructors) {
+      type.constructors.forEach(function(constructor) {
+        searchMethod(constructor, type, "constructor", query, results);
+      })
+    }
+    if (type.macros) {
+      type.macros.forEach(function(macro) {
+        searchMethod(macro, type, "macro", query, results);
+      })
+    }
+    if (type.constants) {
+      type.constants.forEach(function(constant){
+        searchConstant(constant, type, query, results);
+      });
+    }
+    if (type.types) {
+      type.types.forEach(function(subtype){
+        searchType(subtype, query, results);
+      });
+    }
   };
 
   function searchMethod(method, type, kind, query, results) {
@@ -75,13 +86,15 @@ CrystalDocs.runQuery = function(query) {
       matchedFields.push("name");
     }
 
-    method.args.forEach(function(arg){
-      var argMatches = query.matches(arg.external_name);
-      if (argMatches) {
-        matches = matches.concat(argMatches);
-        matchedFields.push("args");
-      }
-    });
+    if (method.args) {
+      method.args.forEach(function(arg){
+        var argMatches = query.matches(arg.external_name);
+        if (argMatches) {
+          matches = matches.concat(argMatches);
+          matchedFields.push("args");
+        }
+      });
+    }
 
     var docMatches = query.matches(type.doc);
     if(docMatches){
@@ -96,14 +109,14 @@ CrystalDocs.runQuery = function(query) {
         matches = matches.concat(typeMatches);
       }
       results.push({
-        id: method.id,
+        id: method.html_id,
         type: type.full_name,
         result_type: kind,
         name: method.name,
         full_name: type.full_name + "#" + method.name,
         args_string: method.args_string,
         summary: method.summary,
-        href: type.path + "#" + method.id,
+        href: type.path + "#" + method.html_id,
         matched_fields: matchedFields,
         matched_terms: matches
       });
@@ -130,14 +143,14 @@ CrystalDocs.runQuery = function(query) {
         matches = matches.concat(typeMatches);
       }
       results.push({
-        id: constant.id,
+        id: constant.html_id,
         type: type.full_name,
         result_type: "constant",
         name: constant.name,
         full_name: type.full_name + "#" + constant.name,
         value: constant.value,
         summary: constant.summary,
-        href: type.path + "#" + constant.id,
+        href: type.path + "#" + constant.html_id,
         matched_fields: matchedFields,
         matched_terms: matches
       });
